@@ -1,4 +1,4 @@
-package Finance::CoinbasePro::API::CLI;
+package Finance::CoinbasePro::API::CLI; # Command-line interface to GDAX / Coinbase Pro
 
 use 5.006;
 use strict;
@@ -10,7 +10,8 @@ Finance::CoinbasePro::API::CLI - Command-line interface to GDAX / Coinbase Pro
 
 =cut
 
-our $VERSION = '0.000_13';
+our $VERSION = '0.000_14'; # TRIAL
+$VERSION =~ tr/_//d;
 
 
 =head1 SYNOPSIS
@@ -95,11 +96,13 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI
+Finance::CoinbasePro::API::CLI - Command-line interface to GDAX / Coinbase Pro
 
 
 =head1 DESCRIPTION
@@ -114,5 +117,6 @@ L<5.006>
 
 =head1 METHODS
 
+
 =cut
 
