@@ -1,5 +1,4 @@
-package Finance::CoinbasePro::API::CLI::Fill;
-# this knows about Finance::GDAX::Fill objects and can display them
+package Finance::CoinbasePro::API::CLI::Fill; # this knows about Finance::GDAX::Fill objects and can display them
 use Mouse;
 use Finance::CoinbasePro::API::CLI::Util::CurrencyUtil qw(format_currency);
 use Finance::CoinbasePro::API::CLI::Util::DateUtil qw(getdatetime convert_seconds_to_human_time my_str2time);
@@ -100,16 +99,18 @@ user_id => "513378df5210ff660900002b",
 
 
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI::Fill - CoinbasePro Filled Trade Object
+Finance::CoinbasePro::API::CLI::Fill - this knows about Finance::GDAX::Fill objects and can display them
 
 
 =head1 DESCRIPTION
 
-this knows about Finance::GDAX::Fill objects and can display them
+returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,000.00, cost $70,000.00'
 
 
 =head1 REQUIRES
@@ -155,5 +156,7 @@ L<Mouse>
 
 returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,000.00, cost $70,000.00'
 
+
+
 =cut
 
