@@ -1,4 +1,4 @@
-package Finance::CoinbasePro::API::CLI::Util::CurrencyUtil;
+package Finance::CoinbasePro::API::CLI::Util::CurrencyUtil; # formats values in currencies for display
 use strict;
 
 use base qw(Exporter);
@@ -125,6 +125,8 @@ sub _log10 { my $n = shift; return 2 unless $n; return log($n)/log(10); }
 
 
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -179,5 +181,6 @@ L<Exporter>
 
  $self->get_product_currencies();
 
+
 =cut
 
